##  Creating and Implementing a Future-State/To-Be-State Plan
After conducting an application portfolio assessment, the next step is to create and implement a future state or to-be-state plan. This involves defining a transformation roadmap based on the findings and decisions made during the assessment. If there are already decisions for specific applications, those can be aggregated and incorporated into the roadmap.
[SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning?locale=en-US&state=PRODUCTION&version=CLOUD "The SAP LeanIX Architecture and Road Map Planning enhances SAP LeanIX Application Portfolio Management by offering advanced features for seamless planning and execution of transformation initiatives in enterprise architecture management.") provides valuable functionality to structure and manage the transformation program using initiative fact sheets.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b14067a441014b373dae23c0f30d8_LowRes.png)
While developing the to-be state plan, the pace layering of business capabilities makes it easier to identify if budget allocations align with strategic priorities. If investments heavily favor "Commodity" capabilities while the strategic focus is on "Innovation" and "Differentiation", adjustments can be made to reallocate resources accordingly. This ensures that investments are aligned with the organization's strategic objectives.
Regular reassessment of the pace layering classification is recommended whenever the organization's business and IT strategies change. This ensures that the classification remains aligned with the organization's strategic goals.
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
